@@ -1,7 +1,10 @@
 # -*- coding: utf-8 -*-
 """
 Django Extensions additional model fields
+
+Some fields might require additional dependencies to be installed.
 """
+
 import re
 import six
 import string
@@ -56,7 +59,7 @@ class UniqueFieldMixin(object):
         if model_instance.pk:
             queryset = queryset.exclude(pk=model_instance.pk)
 
-        # form a kwarg dict used to impliment any unique_together contraints
+        # form a kwarg dict used to implement any unique_together constraints
         kwargs = {}
         for params in model_instance._meta.unique_together:
             if self.attname in params:
@@ -73,7 +76,8 @@ class UniqueFieldMixin(object):
 
 
 class AutoSlugField(UniqueFieldMixin, SlugField):
-    """ AutoSlugField
+    """
+    AutoSlugField
 
     By default, sets editable=False, blank=True.
 
@@ -95,9 +99,38 @@ class AutoSlugField(UniqueFieldMixin, SlugField):
     overwrite
         If set to True, overwrites the slug on every save (default: False)
 
+    slugify_function
+        Defines the function which will be used to "slugify" a content
+        (default: :py:func:`~django.template.defaultfilters.slugify` )
+
+    It is possible to provide custom "slugify" function with
+    the ``slugify_function`` function in a model class.
+
+    ``slugify_function`` function in a model class takes priority over
+    ``slugify_function`` given as an argument to :py:class:`~AutoSlugField`.
+
+    Example
+
+    .. code-block:: python
+
+        # models.py
+
+        from django.db import models
+
+        from django_extensions.db.fields import AutoSlugField
+
+
+        class MyModel(models.Model):
+            def slugify_function(self, content):
+                return content.replace('_', '-').lower()
+
+            title = models.CharField(max_length=42)
+            slug = AutoSlugField(populate_from='title')
+
     Inspired by SmileyChris' Unique Slugify snippet:
     http://www.djangosnippets.org/snippets/690/
     """
+
     def __init__(self, *args, **kwargs):
         kwargs.setdefault('blank', True)
         kwargs.setdefault('editable', False)
@@ -108,10 +141,19 @@ class AutoSlugField(UniqueFieldMixin, SlugField):
         else:
             self._populate_from = populate_from
 
+        if not callable(populate_from):
+            if not isinstance(populate_from, (list, tuple)):
+                populate_from = (populate_from, )
+
+            if not all(isinstance(e, six.string_types) for e in populate_from):
+                raise TypeError("'populate_from' must be str or list[str] or tuple[str], found `%s`" % populate_from)
+
         self.slugify_function = kwargs.pop('slugify_function', slugify)
         self.separator = kwargs.pop('separator', six.u('-'))
         self.overwrite = kwargs.pop('overwrite', False)
         self.check_is_bool('overwrite')
+        self.overwrite_on_add = kwargs.pop('overwrite_on_add', True)
+        self.check_is_bool('overwrite_on_add')
         self.allow_duplicates = kwargs.pop('allow_duplicates', False)
         self.check_is_bool('allow_duplicates')
         self.max_unique_query_attempts = kwargs.pop('max_unique_query_attempts', MAX_UNIQUE_QUERY_ATTEMPTS)
@@ -119,7 +161,7 @@ class AutoSlugField(UniqueFieldMixin, SlugField):
 
     def _slug_strip(self, value):
         """
-        Cleans up a slug by removing slug separator characters that occur at
+        Clean up a slug by removing slug separator characters that occur at
         the beginning or end of a slug.
 
         If an alternate separator is used, it will also replace any instances
@@ -129,9 +171,10 @@ class AutoSlugField(UniqueFieldMixin, SlugField):
         value = re.sub('%s+' % re_sep, self.separator, value)
         return re.sub(r'^%s+|%s+$' % (re_sep, re_sep), '', value)
 
-    def slugify_func(self, content):
+    @staticmethod
+    def slugify_func(content, slugify_function):
         if content:
-            return self.slugify_function(content)
+            return slugify_function(content)
         return ''
 
     def slug_generator(self, original_slug, start):
@@ -148,23 +191,35 @@ class AutoSlugField(UniqueFieldMixin, SlugField):
         raise RuntimeError('max slug attempts for %s exceeded (%s)' % (original_slug, self.max_unique_query_attempts))
 
     def create_slug(self, model_instance, add):
-        # get fields to populate from and slug field to set
-        if not isinstance(self._populate_from, (list, tuple)):
-            self._populate_from = (self._populate_from, )
-        slug_field = model_instance._meta.get_field(self.attname)
+        slug = getattr(model_instance, self.attname)
+        use_existing_slug = False
+        if slug and not self.overwrite:
+            # Existing slug and not configured to overwrite - Short-circuit
+            # here to prevent slug generation when not required.
+            use_existing_slug = True
 
-        if add or self.overwrite:
-            # slugify the original field content and set next step to 2
-            slug_for_field = lambda lookup_value: self.slugify_func(self.get_slug_fields(model_instance, lookup_value))
-            slug = self.separator.join(map(slug_for_field, self._populate_from))
-            start = 2
-        else:
-            # get slug from the current model instance
-            slug = getattr(model_instance, self.attname)
-            # model_instance is being modified, and overwrite is False,
-            # so instead of doing anything, just return the current slug
+        if self.overwrite_on_add and add:
+            use_existing_slug = False
+
+        if use_existing_slug:
             return slug
 
+        # get fields to populate from and slug field to set
+        populate_from = self._populate_from
+        if not isinstance(populate_from, (list, tuple)):
+            populate_from = (populate_from, )
+
+        slug_field = model_instance._meta.get_field(self.attname)
+        slugify_function = getattr(model_instance, 'slugify_function', self.slugify_function)
+
+        # slugify the original field content and set next step to 2
+        slug_for_field = lambda lookup_value: self.slugify_func(
+            self.get_slug_fields(model_instance, lookup_value),
+            slugify_function=slugify_function
+        )
+        slug = self.separator.join(map(slug_for_field, populate_from))
+        start = 2
+
         # strip slug depending on max_length attribute of the slug field
         # and clean-up
         self.slug_len = slug_field.max_length
@@ -181,6 +236,10 @@ class AutoSlugField(UniqueFieldMixin, SlugField):
             model_instance, slug_field, self.slug_generator(original_slug, start))
 
     def get_slug_fields(self, model_instance, lookup_value):
+        if callable(lookup_value):
+            # A function has been provided
+            return "%s" % lookup_value(model_instance)
+
         lookup_value_path = lookup_value.split(LOOKUP_SEP)
         attr = model_instance
         for elem in lookup_value_path:
@@ -216,7 +275,8 @@ class AutoSlugField(UniqueFieldMixin, SlugField):
 
 
 class RandomCharField(UniqueFieldMixin, CharField):
-    """ RandomCharField
+    """
+    RandomCharField
 
     By default, sets editable=False, blank=True, unique=False.
 
@@ -245,6 +305,7 @@ class RandomCharField(UniqueFieldMixin, CharField):
     include_punctuation
         If set to True, include punctuation characters (default: False)
     """
+
     def __init__(self, *args, **kwargs):
         kwargs.setdefault('blank', True)
         kwargs.setdefault('editable', False)
@@ -333,7 +394,8 @@ class RandomCharField(UniqueFieldMixin, CharField):
 
 
 class CreationDateTimeField(DateTimeField):
-    """ CreationDateTimeField
+    """
+    CreationDateTimeField
 
     By default, sets editable=False, blank=True, auto_now_add=True
     """
@@ -359,7 +421,8 @@ class CreationDateTimeField(DateTimeField):
 
 
 class ModificationDateTimeField(CreationDateTimeField):
-    """ ModificationDateTimeField
+    """
+    ModificationDateTimeField
 
     By default, sets editable=False, blank=True, auto_now=True
 
@@ -381,7 +444,7 @@ class ModificationDateTimeField(CreationDateTimeField):
 
     def pre_save(self, model_instance, add):
         if not getattr(model_instance, 'update_modified', True):
-            return model_instance.modified
+            return getattr(model_instance, self.attname)
         return super(ModificationDateTimeField, self).pre_save(model_instance, add)
 
 
@@ -390,13 +453,15 @@ class UUIDVersionError(Exception):
 
 
 class UUIDFieldMixin(object):
-    """ UUIDFieldMixin
+    """
+    UUIDFieldMixin
 
     By default uses UUID version 4 (randomly generated UUID).
 
     The field support all uuid versions which are natively supported by the uuid python module, except version 2.
     For more information see: http://docs.python.org/lib/module-uuid.html
     """
+
     DEFAULT_MAX_LENGTH = 36
 
     def __init__(
@@ -478,12 +543,14 @@ class UUIDFieldMixin(object):
 
 
 class ShortUUIDField(UUIDFieldMixin, CharField):
-    """ ShortUUIDFied
+    """
+    ShortUUIDFied
 
     Generates concise (22 characters instead of 36), unambiguous, URL-safe UUIDs.
 
     Based on `shortuuid`: https://github.com/stochastic-technologies/shortuuid
     """
+
     DEFAULT_MAX_LENGTH = 22
 
     def __init__(self, *args, **kwargs):
