@@ -28,37 +28,30 @@ Improvements:
     See TODOs and FIXMEs scattered throughout :-)
 
 """
-
 import datetime
 import sys
 
-import django
 import six
-# conditional import, force_unicode was renamed in Django 1.5
+from django.apps import apps
 from django.contrib.contenttypes.models import ContentType
 from django.core.exceptions import ObjectDoesNotExist
+from django.core.management.base import BaseCommand
+from django.db import router
 from django.db.models import (
     AutoField, BooleanField, DateField, DateTimeField, FileField, ForeignKey,
 )
+from django.db.models.deletion import Collector
+from django.utils import timezone
+from django.utils.encoding import force_text, smart_text
 
 from django_extensions.management.utils import signalcommand
-from django_extensions.compat import (
-    list_app_labels, get_model_compat, get_models_for_app
-)
-from django_extensions.compat import CompatibilityBaseCommand as BaseCommand
-
-try:
-    from django.utils.encoding import smart_unicode, force_unicode  # NOQA
-except ImportError:
-    from django.utils.encoding import smart_text as smart_unicode, force_text as force_unicode  # NOQA
 
 
 def orm_item_locator(orm_obj):
     """
-    This function is called every time an object that will not be exported is required.
+    Is called every time an object that will not be exported is required.
     Where orm_obj is the referred object.
     We postpone the lookup to locate_object() which will be run on the generated script
-
     """
 
     the_class = orm_obj._meta.object_name
@@ -76,27 +69,35 @@ def orm_item_locator(orm_obj):
 
     for key in clean_dict:
         v = clean_dict[key]
-        if v is not None and not isinstance(v, (six.string_types, six.integer_types, float, datetime.datetime)):
-            clean_dict[key] = six.u("%s" % v)
+        if v is not None:
+            if isinstance(v, datetime.datetime):
+                v = timezone.make_aware(v)
+                clean_dict[key] = StrToCodeChanger('dateutil.parser.parse("%s")' % v.isoformat())
+            elif not isinstance(v, (six.string_types, six.integer_types, float)):
+                clean_dict[key] = six.u("%s" % v)
 
     output = """ importer.locate_object(%s, "%s", %s, "%s", %s, %s ) """ % (
         original_class, original_pk_name,
         the_class, pk_name, pk_value, clean_dict
     )
+
     return output
 
 
 class Command(BaseCommand):
     help = 'Dumps the data as a customised python script.'
-    args = '[appname ...]'
 
     def add_arguments(self, parser):
+        super(Command, self).add_arguments(parser)
+        parser.add_argument('appname', nargs='+')
         parser.add_argument(
             '--autofield', action='store_false', dest='skip_autofield',
-            default=True, help='Include Autofields (like pk fields)')
+            default=True, help='Include Autofields (like pk fields)'
+        )
 
     @signalcommand
-    def handle(self, *app_labels, **options):
+    def handle(self, *args, **options):
+        app_labels = options['appname']
 
         # Get the models we want to export
         models = get_models(app_labels)
@@ -119,9 +120,10 @@ class Command(BaseCommand):
 
 
 def get_models(app_labels):
-    """ Gets a list of models for the given app labels, with some exceptions.
-        TODO: If a required model is referenced, it should also be included.
-        Or at least discovered with a get_or_create() call.
+    """
+    Get a list of models for the given app labels, with some exceptions.
+    TODO: If a required model is referenced, it should also be included.
+    Or at least discovered with a get_or_create() call.
     """
 
     # These models are not to be output, e.g. because they can be generated automatically
@@ -132,8 +134,8 @@ def get_models(app_labels):
 
     # If no app labels are given, return all
     if not app_labels:
-        for app_label in list_app_labels():
-            models += [m for m in get_models_for_app(app_label)
+        for app in apps.get_app_configs():
+            models += [m for m in apps.get_app_config(app.label).get_models()
                        if m not in EXCLUDED_MODELS]
         return models
 
@@ -142,20 +144,21 @@ def get_models(app_labels):
         # If a specific model is mentioned, get only that model
         if "." in app_label:
             app_label, model_name = app_label.split(".", 1)
-            models.append(get_model_compat(app_label, model_name))
+            models.append(apps.get_model(app_label, model_name))
         # Get all models for a given app
         else:
-            models += [m for m in get_models_for_app(app_label)
+            models += [m for m in apps.get_app_config(app_label).get_models()
                        if m not in EXCLUDED_MODELS]
 
     return models
 
 
 class Code(object):
-    """ A snippet of python script.
-        This keeps track of import statements and can be output to a string.
-        In the future, other features such as custom indentation might be included
-        in this class.
+    """
+    A snippet of python script.
+    This keeps track of import statements and can be output to a string.
+    In the future, other features such as custom indentation might be included
+    in this class.
     """
 
     def __init__(self, indent=-1, stdout=None, stderr=None):
@@ -170,8 +173,7 @@ class Code(object):
         self.stderr = stderr
 
     def __str__(self):
-        """ Returns a string representation of this script.
-        """
+        """ Return a string representation of this script. """
         if self.imports:
             self.stderr.write(repr(self.import_lines))
             return flatten_blocks([""] + self.import_lines + [""] + self.lines, num_indents=self.indent)
@@ -179,8 +181,7 @@ class Code(object):
             return flatten_blocks(self.lines, num_indents=self.indent)
 
     def get_import_lines(self):
-        """ Takes the stored imports and converts them to lines
-        """
+        """ Take the stored imports and converts them to lines """
         if self.imports:
             return ["from %s import %s" % (value, key) for key, value in self.imports.items()]
         else:
@@ -201,15 +202,17 @@ class ModelCode(Code):
         self.instances = []
 
     def get_imports(self):
-        """ Returns a dictionary of import statements, with the variable being
-            defined as the key.
         """
-        return {self.model.__name__: smart_unicode(self.model.__module__)}
+        Return a dictionary of import statements, with the variable being
+        defined as the key.
+        """
+        return {self.model.__name__: smart_text(self.model.__module__)}
     imports = property(get_imports)
 
     def get_lines(self):
-        """ Returns a list of lists or strings, representing the code body.
-            Each list is a block, each string is a statement.
+        """
+        Return a list of lists or strings, representing the code body.
+        Each list is a block, each string is a statement.
         """
         code = []
 
@@ -253,15 +256,21 @@ class InstanceCode(Code):
 
         self.many_to_many_waiting_list = {}
         for field in self.model._meta.many_to_many:
+            try:
+                if not field.remote_field.through._meta.auto_created:
+                    continue
+            except AttributeError:
+                pass
             self.many_to_many_waiting_list[field] = list(getattr(self.instance, field.name).all())
 
     def get_lines(self, force=False):
-        """ Returns a list of lists or strings, representing the code body.
-            Each list is a block, each string is a statement.
+        """
+        Return a list of lists or strings, representing the code body.
+        Each list is a block, each string is a statement.
 
-            force (True or False): if an attribute object cannot be included,
-            it is usually skipped to be processed later. With 'force' set, there
-            will be no waiting: a get_or_create() call is written instead.
+        force (True or False): if an attribute object cannot be included,
+        it is usually skipped to be processed later. With 'force' set, there
+        will be no waiting: a get_or_create() call is written instead.
         """
         code_lines = []
 
@@ -293,70 +302,22 @@ class InstanceCode(Code):
     lines = property(get_lines)
 
     def skip(self):
-        """ Determine whether or not this object should be skipped.
-            If this model instance is a parent of a single subclassed
-            instance, skip it. The subclassed instance will create this
-            parent instance for us.
-
-            TODO: Allow the user to force its creation?
         """
+        Determine whether or not this object should be skipped.
+        If this model instance is a parent of a single subclassed
+        instance, skip it. The subclassed instance will create this
+        parent instance for us.
 
+        TODO: Allow the user to force its creation?
+        """
         if self.skip_me is not None:
             return self.skip_me
 
-        def get_skip_version():
-            """ Return which version of the skip code should be run
-
-                Django's deletion code was refactored in r14507 which
-                was just two days before 1.3 alpha 1 (r14519)
-            """
-            if not hasattr(self, '_SKIP_VERSION'):
-                version = django.VERSION
-                # no, it isn't lisp. I swear.
-                self._SKIP_VERSION = (
-                    version[0] > 1 or (  # django 2k... someday :)
-                        version[0] == 1 and (  # 1.x
-                            version[1] >= 4 or  # 1.4+
-                            version[1] == 3 and not (  # 1.3.x
-                                (version[3] == 'alpha' and version[1] == 0)
-                            )
-                        )
-                    )
-                ) and 2 or 1  # NOQA
-            return self._SKIP_VERSION
-
-        if get_skip_version() == 1:
-            try:
-                # Django trunk since r7722 uses CollectedObjects instead of dict
-                from django.db.models.query import CollectedObjects
-                sub_objects = CollectedObjects()
-            except ImportError:
-                # previous versions don't have CollectedObjects
-                sub_objects = {}
-            self.instance._collect_sub_objects(sub_objects)
-            sub_objects = sub_objects.keys()
-
-        elif get_skip_version() == 2:
-            from django.db.models.deletion import Collector
-            from django.db import router
-            cls = self.instance.__class__
-            using = router.db_for_write(cls, instance=self.instance)
-            collector = Collector(using=using)
-            collector.collect([self.instance], collect_related=False)
-
-            # collector stores its instances in two places. I *think* we
-            # only need collector.data, but using the batches is needed
-            # to perfectly emulate the old behaviour
-            # TODO: check if batches are really needed. If not, remove them.
-            sub_objects = sum([list(i) for i in collector.data.values()], [])
-
-            if hasattr(collector, 'batches'):
-                # Django 1.6 removed batches for being dead code
-                # https://github.com/django/django/commit/a170c3f755351beb35f8166ec3c7e9d524d9602
-                for batch in collector.batches.values():
-                    # batch.values can be sets, which must be converted to lists
-                    sub_objects += sum([list(i) for i in batch.values()], [])
-
+        cls = self.instance.__class__
+        using = router.db_for_write(cls, instance=self.instance)
+        collector = Collector(using=using)
+        collector.collect([self.instance], collect_related=False)
+        sub_objects = sum([list(i) for i in collector.data.values()], [])
         sub_objects_parents = [so._meta.parents for so in sub_objects]
         if [self.model in p for p in sub_objects_parents].count(True) == 1:
             # since this instance isn't explicitly created, it's variable name
@@ -390,7 +351,7 @@ class InstanceCode(Code):
         """ Add lines for any waiting fields that can be completed now. """
 
         code_lines = []
-        skip_autofield = self.options.get('skip_autofield', True)
+        skip_autofield = self.options['skip_autofield']
 
         # Process normal fields
         for field in list(self.waiting_list):
@@ -410,7 +371,7 @@ class InstanceCode(Code):
         return code_lines
 
     def get_many_to_many_lines(self, force=False):
-        """ Generates lines that define many to many relations for this instance. """
+        """ Generate lines that define many to many relations for this instance. """
 
         lines = []
 
@@ -453,16 +414,15 @@ class Script(Code):
         self.options = options
 
     def _queue_models(self, models, context):
-        """ Works an an appropriate ordering for the models.
-            This isn't essential, but makes the script look nicer because
-            more instances can be defined on their first try.
         """
-
-        # Max number of cycles allowed before we call it an infinite loop.
-        MAX_CYCLES = 5
-
+        Work an an appropriate ordering for the models.
+        This isn't essential, but makes the script look nicer because
+        more instances can be defined on their first try.
+        """
         model_queue = []
         number_remaining_models = len(models)
+        # Max number of cycles allowed before we call it an infinite loop.
+        MAX_CYCLES = number_remaining_models
         allowed_cycles = MAX_CYCLES
 
         while number_remaining_models > 0:
@@ -499,8 +459,9 @@ class Script(Code):
         return model_queue
 
     def get_lines(self):
-        """ Returns a list of lists or strings, representing the code body.
-            Each list is a block, each string is a statement.
+        """
+        Return a list of lists or strings, representing the code body.
+        Each list is a block, each string is a statement.
         """
         code = [self.FILE_HEADER.strip()]
 
@@ -569,9 +530,7 @@ class BasicImportHelper(object):
     def pre_import(self):
         pass
 
-    # You probably want to uncomment on of these two lines
-    # @transaction.atomic  # Django 1.6
-    # @transaction.commit_on_success  # Django <1.6
+    @transaction.atomic
     def run_import(self, import_data):
         import_data()
 
@@ -654,6 +613,7 @@ from django.contrib.contenttypes.models import ContentType
 
 try:
     import dateutil.parser
+    from dateutil.tz import tzoffset
 except ImportError:
     print("Please install python-dateutil")
     sys.exit(os.EX_USAGE)
@@ -672,10 +632,10 @@ def import_data():
 # -------------------------------------------------------------------------------
 
 def flatten_blocks(lines, num_indents=-1):
-    """ Takes a list (block) or string (statement) and flattens it into a string
-        with indentation.
     """
-
+    Take a list (block) or string (statement) and flattens it into a string
+    with indentation.
+    """
     # The standard indent is four spaces
     INDENTATION = " " * 4
 
@@ -691,8 +651,7 @@ def flatten_blocks(lines, num_indents=-1):
 
 
 def get_attribute_value(item, field, context, force=False, skip_autofield=True):
-    """ Gets a string version of the given attribute's value, like repr() might. """
-
+    """ Get a string version of the given attribute's value, like repr() might. """
     # Find the value of the field, catching any database issues
     try:
         value = getattr(item, field.name)
@@ -709,7 +668,7 @@ def get_attribute_value(item, field, context, force=False, skip_autofield=True):
 
     # Post file-storage-refactor, repr() on File/ImageFields no longer returns the path
     elif isinstance(field, FileField):
-        return repr(force_unicode(value))
+        return repr(force_text(value))
 
     # ForeignKey fields, link directly using our stored python variable name
     elif isinstance(field, ForeignKey) and value is not None:
@@ -718,7 +677,7 @@ def get_attribute_value(item, field, context, force=False, skip_autofield=True):
         # content types in this script, as they can be generated again
         # automatically.
         # NB: Not sure if "is" will always work
-        if field.rel.to is ContentType:
+        if field.remote_field.model is ContentType:
             return 'ContentType.objects.get(app_label="%s", model="%s")' % (value.app_label, value.model)
 
         # Generate an identifier (key) for this foreign object
@@ -758,20 +717,23 @@ def make_clean_dict(the_dict):
 
 def check_dependencies(model, model_queue, avaliable_models):
     """ Check that all the depenedencies for this model are already in the queue. """
-
     # A list of allowed links: existing fields, itself and the special case ContentType
     allowed_links = [m.model.__name__ for m in model_queue] + [model.__name__, 'ContentType']
 
     # For each ForeignKey or ManyToMany field, check that a link is possible
 
     for field in model._meta.fields:
-        if field.rel and field.rel.to.__name__ not in allowed_links:
-            if field.rel.to not in avaliable_models:
+        if not field.remote_field:
+            continue
+        if field.remote_field.model.__name__ not in allowed_links:
+            if field.remote_field.model not in avaliable_models:
                 continue
             return False
 
     for field in model._meta.many_to_many:
-        if field.rel and field.rel.to.__name__ not in allowed_links:
+        if not field.remote_field:
+            continue
+        if field.remote_field.model.__name__ not in allowed_links:
             return False
 
     return True
@@ -786,3 +748,12 @@ class SkipValue(Exception):
 
 class DoLater(Exception):
     """ Value could not be parsed or should simply be skipped. """
+
+
+class StrToCodeChanger:
+
+    def __init__(self, string):
+        self.repr = string
+
+    def __repr__(self):
+        return self.repr
