@@ -14,13 +14,13 @@ from django.core.exceptions import ImproperlyConfigured
 from django.core.management.base import BaseCommand, CommandError
 from django.core.servers.basehttp import get_internal_wsgi_application
 from django.db.backends import utils
-from django.utils.autoreload import gen_filenames
+try:
+    from django.utils.autoreload import gen_filenames
+except ImportError:  # Django >=2.2
+    from django.utils.autoreload import get_reloader
 
-from django_extensions.management.technical_response import \
-    null_technical_500_response
-from django_extensions.management.utils import (
-    RedirectHandler, has_ipdb, setup_logger, signalcommand,
-)
+    def gen_filenames():
+        return get_reloader().watched_files()
 
 try:
     if 'whitenoise.runserver_nostatic' in settings.INSTALLED_APPS:
@@ -36,6 +36,10 @@ try:
 except ImportError:
     USE_STATICFILES = False
 
+from django_extensions.management.technical_response import null_technical_500_response
+from django_extensions.management.utils import RedirectHandler, has_ipdb, setup_logger, signalcommand
+
+
 naiveip_re = re.compile(r"""^(?:
 (?P<addr>
     (?P<ipv4>\d{1,3}(?:\.\d{1,3}){3}) |         # IPv4 address
@@ -54,6 +58,8 @@ class Command(BaseCommand):
 
     # Validation is called explicitly each time the server is reloaded.
     requires_system_checks = False
+    DEFAULT_CRT_EXTENSION = ".crt"
+    DEFAULT_KEY_EXTENSION = ".key"
 
     def add_arguments(self, parser):
         super(Command, self).add_arguments(parser)
@@ -77,7 +83,7 @@ class Command(BaseCommand):
         cert_group.add_argument('--cert', dest='cert_path', action="store", type=str,
                                 help='Deprecated alias for --cert-file option.')
         cert_group.add_argument('--cert-file', dest='cert_path', action="store", type=str,
-                                help='SSL .cert file path. If not provided path from --key-file will be selected. '
+                                help='SSL .crt file path. If not provided path from --key-file will be selected. '
                                      'Either --cert-file or --key-file must be provided to use SSL.')
         parser.add_argument('--key-file', dest='key_file_path', action="store", type=str,
                             help='SSL .key file path. If not provided path from --cert-file will be selected. '
@@ -353,7 +359,7 @@ class Command(BaseCommand):
             webbrowser.open(bind_url)
 
         if use_reloader and settings.USE_I18N:
-            extra_files.extend(filter(lambda filename: filename.endswith('.mo'), gen_filenames()))
+            extra_files.extend(filter(lambda filename: str(filename).endswith('.mo'), gen_filenames()))
 
         # Werkzeug needs to be clued in its the main instance if running
         # without reloader or else it won't show key.
@@ -382,42 +388,40 @@ class Command(BaseCommand):
             ssl_context=ssl_context,
         )
 
-    @classmethod
-    def _create_path_with_extension_from(cls, file_path, extension):
-        dir_path, cert_file = os.path.split(file_path)
-        if not dir_path:
-            dir_path = os.getcwd()
-        file_name, _ = os.path.splitext(cert_file)
-        return os.path.join(dir_path, file_name + "." + extension)
-
-    @classmethod
-    def _determine_path_for_file(cls, current_file, other_file, extension):
-        """ Determine path with proper extension. If path is absent then use path from alternative file.
-        If path is relative than use current working directory.
-        :param current_file: path for current file
-        :param other_file: path for alternative file
-        :param extension: expected extension
-        :return: path of this file.
-        """
-        if current_file is None:
-            return cls._create_path_with_extension_from(other_file, extension)
-        directory, file = os.path.split(current_file)
-        file_name, _ = os.path.splitext(file)
-        if not directory:
-            return cls._create_path_with_extension_from(current_file, extension)
-        else:
-            return os.path.join(directory, file_name + "." + extension)
-
     @classmethod
     def determine_ssl_files_paths(cls, options):
-        cert_file = cls._determine_path_for_file(options['cert_path'], options['key_file_path'], "crt")
-        key_file = cls._determine_path_for_file(options['key_file_path'], options['cert_path'], "key")
+        key_file_path = options.get('key_file_path') or ""
+        cert_path = options.get('cert_path') or ""
+        cert_file = cls._determine_path_for_file(cert_path, key_file_path, cls.DEFAULT_CRT_EXTENSION)
+        key_file = cls._determine_path_for_file(key_file_path, cert_path, cls.DEFAULT_KEY_EXTENSION)
         return cert_file, key_file
 
+    @classmethod
+    def _determine_path_for_file(cls, current_file_path, other_file_path, expected_extension):
+        directory = cls._get_directory_basing_on_file_paths(current_file_path, other_file_path)
+        file_name = cls._get_file_name(current_file_path) or cls._get_file_name(other_file_path)
+        extension = cls._get_extension(current_file_path) or expected_extension
+        return os.path.join(directory, file_name + extension)
+
+    @classmethod
+    def _get_directory_basing_on_file_paths(cls, current_file_path, other_file_path):
+        return cls._get_directory(current_file_path) or cls._get_directory(other_file_path) or os.getcwd()
+
+    @classmethod
+    def _get_directory(cls, file_path):
+        return os.path.split(file_path)[0]
+
+    @classmethod
+    def _get_file_name(cls, file_path):
+        return os.path.splitext(os.path.split(file_path)[1])[0]
+
+    @classmethod
+    def _get_extension(cls, file_path):
+        return os.path.splitext(file_path)[1]
+
 
 def set_werkzeug_log_color():
-    """Try to set color to the werkzeug log.
-    """
+    """Try to set color to the werkzeug log."""
     from django.core.management.color import color_style
     from werkzeug.serving import WSGIRequestHandler
     from werkzeug._internal import _log
