@@ -1,19 +1,20 @@
 # -*- coding: utf-8 -*-
-import pytest
 import django
+import pytest
+import six
 from django.db import migrations, models
 from django.db.migrations.writer import MigrationWriter
 from django.test import TestCase
-from django.utils import six
 from django.utils.encoding import force_bytes
 
 import django_extensions  # noqa
 from django_extensions.db.fields import AutoSlugField
 
-from .testapp.models import ChildSluggedTestModel, SluggedTestModel, \
-    SluggedTestNoOverwriteOnAddModel, FKSluggedTestModel, \
-    FKSluggedTestModelCallable, FunctionSluggedTestModel, \
-    ModelMethodSluggedTestModel
+from .testapp.models import (
+    ChildSluggedTestModel, CustomFuncPrecedenceSluggedTestModel, CustomFuncSluggedTestModel,
+    FKSluggedTestModel, FKSluggedTestModelCallable, FunctionSluggedTestModel,
+    ModelMethodSluggedTestModel, SluggedTestModel, SluggedTestNoOverwriteOnAddModel,
+)
 
 
 @pytest.mark.usefixtures("admin_user")
@@ -22,6 +23,8 @@ class AutoSlugFieldTest(TestCase):
         super(AutoSlugFieldTest, self).tearDown()
 
         SluggedTestModel.objects.all().delete()
+        CustomFuncSluggedTestModel.objects.all().delete()
+        CustomFuncPrecedenceSluggedTestModel.objects.all().delete()
 
     def test_auto_create_slug(self):
         m = SluggedTestModel(title='foo')
@@ -186,6 +189,34 @@ class AutoSlugFieldTest(TestCase):
         m.save()
         self.assertEqual(m.slug, 'slug')
 
+    def test_slugify_func(self):
+        to_upper = lambda c: c.upper()
+        to_lower = lambda c: c.lower()
+
+        content_n_func_n_expected = (
+            ('test', to_upper, 'TEST'),
+            ('', to_upper, ''),
+            ('TEST', to_lower, 'test'),
+        )
+
+        for content, slugify_function, expected in content_n_func_n_expected:
+            self.assertEqual(
+                AutoSlugField.slugify_func(content, slugify_function),
+                expected
+            )
+
+    def test_use_custom_slug_function(self):
+        m = CustomFuncSluggedTestModel(title='test')
+        m.save()
+        self.assertEqual(m.slug, 'TEST')
+
+    def test_precedence_custom_slug_function(self):
+        m = CustomFuncPrecedenceSluggedTestModel(title='test')
+        m.save()
+        self.assertEqual(m.slug, 'TEST')
+        self.assertTrue(hasattr(m._meta.get_field('slug'), 'slugify_function'))
+        self.assertEqual(m._meta.get_field('slug').slugify_function('TEST'), 'test')
+
 
 class MigrationTest(TestCase):
     def safe_exec(self, string, value=None):
@@ -210,9 +241,12 @@ class MigrationTest(TestCase):
 
         migration = type(str("Migration"), (migrations.Migration,), {
             "operations": [
-                migrations.CreateModel("MyModel", tuple(fields.items()),
-                                       {'populate_from': 'otherfield'},
-                                       (models.Model,)),
+                migrations.CreateModel(
+                    "MyModel",
+                    tuple(fields.items()),
+                    {'populate_from': 'otherfield'},
+                    (models.Model,)
+                ),
             ],
         })
         writer = MigrationWriter(migration)
